Name:           pam_mount
Version:        2.19
Release:    1%{?dist}
Summary:        A PAM module that can mount volumes for a user session

License:        LGPLv2+ and (LGPLv2 or LGPLv3) and Public Domain
URL:            http://pam-mount.sourceforge.net/
Source0:        https://downloads.sourceforge.net/pam-mount/%{name}-%{version}.tar.xz
Source1:        https://downloads.sourceforge.net/pam-mount/%{name}-%{version}.tar.asc
Source2:        pam_mount-gpgkey.gpg

Patch0:         pam_mount-2.16-LTINIT.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cryptsetup-devel
BuildRequires:  gcc
BuildRequires:  gpg
BuildRequires:  libHX-devel >= 3.12.1
BuildRequires:  libmount-devel >= 2.20
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  make
BuildRequires:  man-db
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  pcre2-devel
BuildRequires:  perl-interpreter
BuildRequires:  xz

Requires:       libHX >= 3.12.1
Requires:       hxtools
Requires:       pam
Requires:       libcryptmount = %{version}


%description
This module is aimed at environments with central file servers that a user
wishes to mount on login and unmount on logout, such as (semi-)diskless
stations where many users can logon and where statically mounting the entire
/home from a server is a security risk, or listing all possible volumes in
/etc/fstab is not feasible.

* Users can define their own list of volumes without having to change
  (possibly non-writable) global config files.
* Single sign-on feature - the user needs to type the password just once (at login)
* Transparent mount process
* No stored passwords
* Volumes are unmounted on logout, freeing system resources and not leaving
  data exposed.

The module also supports mounting local filesystems of any kind the normal
mount utility supports, with extra code to make sure certain volumes are set up
properly because often they need more  than just a mount call, such as
encrypted volumes. This includes SMB/CIFS, FUSE, dm-crypt and LUKS.

If  you  intend  to use pam_mount to protect volumes on your computer using an
encrypted filesystem system, please know that there are many other issues you
need to consider in order to protect your data. For example, you probably want
to disable or encrypt your swap partition (the cryptoswap can help you do
this). Do not assume  a  system  is  secure  without  carefully  considering
potential threats.


%prep
xzcat %{SOURCE0} | gpgv --quiet --keyring %{SOURCE2} %{SOURCE1} -
%setup -q
%patch0 -p1 -b.LTINIT
./autogen.sh


%build
%configure                     \
  --with-dtd                   \
  --with-slibdir=%{_libdir}    \
  --with-ssbindir=%{_sbindir}
%make_build


%install
%make_install




%files
%doc doc/bugs.txt doc/faq.txt doc/options.txt doc/todo.txt
%doc config/pam_mount.conf.xml
%license LICENSE.GPL2 LICENSE.GPL3 LICENSE.LGPL2 LICENSE.LGPL3
%config(noreplace) %{_sysconfdir}/security/pam_mount.conf.xml
%{_libdir}/security/pam_mount.so
%{_sbindir}/pmvarrun
%{_sbindir}/pmt-ehd
%{_sbindir}/mount.crypt
%{_sbindir}/umount.crypt
%{_sbindir}/mount.crypt_LUKS
%{_sbindir}/umount.crypt_LUKS
%{_sbindir}/mount.crypto_LUKS
%{_sbindir}/umount.crypto_LUKS
%{_mandir}/man5/pam_mount.conf.5*
%{_mandir}/man8/mount.crypt.8*
%{_mandir}/man8/mount.crypt_LUKS.8*
%{_mandir}/man8/mount.crypto_LUKS.8*
%{_mandir}/man8/pam_mount.8*
%{_mandir}/man8/pmt-ehd.8*
%{_mandir}/man8/pmvarrun.8*
%{_mandir}/man8/umount.crypt.8*
%{_mandir}/man8/umount.crypt_LUKS.8*
%{_mandir}/man8/umount.crypto_LUKS.8*
%ghost %{_localstatedir}/run/pam_mount
%dir %{_datadir}/xml/pam_mount/
%dir %{_datadir}/xml/pam_mount/dtd/
%{_datadir}/xml/pam_mount/dtd/pam_mount.conf.xml.dtd

%package -n libcryptmount
Summary: Library to mount crypto images and handle key files
%description -n libcryptmount
libcryptmount takes care of the many steps involved in making a
crypto image (file) available as a mountable block device, including
supplemental key file decryption, loop device setup and crypto device
setup. It supports pam_mount style plain EHD2/OpenSSL images and LUKS
and transparent use of the OS's crypto layer.
%files -n libcryptmount
%{_libdir}/libcryptmount.so
%{_libdir}/libcryptmount.so.0
%{_libdir}/libcryptmount.so.0.0.0

%package -n libcryptmount-devel
Summary: Development files for libcryptmount
Requires: libcryptmount = %{version}
%description -n libcryptmount-devel
libcryptmount takes care of the many steps involved in making a
crypto image (file) available as a mountable block device, including
supplemental key file decryption, loop device setup and crypto device
setup. It supports pam_mount style plain EHD2/OpenSSL images and LUKS
and transparent use of the OS's crypto layer.
%files -n libcryptmount-devel
%{_includedir}/libcryptmount.h
%exclude %{_libdir}/libcryptmount.la
%{_libdir}/pkgconfig/libcryptmount.pc


%changelog
* Tue Aug 27 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.19-1
- initial build
